# Countries List

**Last Update: 2025-03-11**


1. AD - Andorra
2. AE - United Arab Emirates
3. AF - Afghanistan
4. AG - Antigua & Barbuda
5. AI - Anguilla
6. AL - Albania
7. AM - Armenia
8. AO - Angola
9. AQ - Antarctica
10. AR - Argentina
11. AS - Samoa (American)
12. AT - Austria
13. AU - Australia
14. AW - Aruba
15. AX - Åland Islands
16. AZ - Azerbaijan
17. BA - Bosnia & Herzegovina
18. BB - Barbados
19. BD - Bangladesh
20. BE - Belgium
21. BF - Burkina Faso
22. BG - Bulgaria
23. BH - Bahrain
24. BI - Burundi
25. BJ - Benin
26. BL - St Barthelemy
27. BM - Bermuda
28. BN - Brunei
29. BO - Bolivia
30. BQ - Caribbean NL
31. BR - Brazil
32. BS - Bahamas
33. BT - Bhutan
34. BW - Botswana
35. BY - Belarus
36. BZ - Belize
37. CA - Canada
38. CC - Cocos (Keeling) Islands
39. CD - Congo (Dem. Rep.)
40. CF - Central African Rep.
41. CG - Congo (Rep.)
42. CH - Switzerland
43. CI - Côte d'Ivoire
44. CK - Cook Islands
45. CL - Chile
46. CM - Cameroon
47. CN - China
48. CO - Colombia
49. CR - Costa Rica
50. CU - Cuba
51. CV - Cape Verde
52. CW - Curaçao
53. CX - Christmas Island
54. CY - Cyprus
55. CZ - Czech Republic
56. DE - Germany
57. DJ - Djibouti
58. DK - Denmark
59. DM - Dominica
60. DO - Dominican Republic
61. DZ - Algeria
62. EC - Ecuador
63. EE - Estonia
64. EG - Egypt
65. EH - Western Sahara
66. ER - Eritrea
67. ES - Spain
68. ET - Ethiopia
69. FI - Finland
70. FJ - Fiji
71. FK - Falkland Islands
72. FM - Micronesia
73. FO - Faroe Islands
74. FR - France
75. GA - Gabon
76. GB - Britain (UK)
77. GD - Grenada
78. GE - Georgia
79. GF - French Guiana
80. GG - Guernsey
81. GH - Ghana
82. GI - Gibraltar
83. GL - Greenland
84. GM - Gambia
85. GN - Guinea
86. GP - Guadeloupe
87. GQ - Equatorial Guinea
88. GR - Greece
89. GS - South Georgia & the South Sandwich Islands
90. GT - Guatemala
91. GU - Guam
92. GW - Guinea-Bissau
93. GY - Guyana
94. HK - Hong Kong
95. HN - Honduras
96. HR - Croatia
97. HT - Haiti
98. HU - Hungary
99. ID - Indonesia
100. IE - Ireland
101. IL - Israel
102. IM - Isle of Man
103. IN - India
104. IO - British Indian Ocean Territory
105. IQ - Iraq
106. IR - Iran
107. IS - Iceland
108. IT - Italy
109. JE - Jersey
110. JM - Jamaica
111. JO - Jordan
112. JP - Japan
113. KE - Kenya
114. KG - Kyrgyzstan
115. KH - Cambodia
116. KI - Kiribati
117. KM - Comoros
118. KN - St Kitts & Nevis
119. KP - Korea (North)
120. KR - Korea (South)
121. KW - Kuwait
122. KY - Cayman Islands
123. KZ - Kazakhstan
124. LA - Laos
125. LB - Lebanon
126. LC - St Lucia
127. LI - Liechtenstein
128. LK - Sri Lanka
129. LR - Liberia
130. LS - Lesotho
131. LT - Lithuania
132. LU - Luxembourg
133. LV - Latvia
134. LY - Libya
135. MA - Morocco
136. MC - Monaco
137. MD - Moldova
138. ME - Montenegro
139. MF - St Martin (French)
140. MG - Madagascar
141. MH - Marshall Islands
142. MK - North Macedonia
143. ML - Mali
144. MM - Myanmar (Burma)
145. MN - Mongolia
146. MO - Macau
147. MP - Northern Mariana Islands
148. MQ - Martinique
149. MR - Mauritania
150. MS - Montserrat
151. MT - Malta
152. MU - Mauritius
153. MV - Maldives
154. MW - Malawi
155. MX - Mexico
156. MY - Malaysia
157. MZ - Mozambique
158. NA - Namibia
159. NC - New Caledonia
160. NE - Niger
161. NF - Norfolk Island
162. NG - Nigeria
163. NI - Nicaragua
164. NL - Netherlands
165. NO - Norway
166. NP - Nepal
167. NR - Nauru
168. NU - Niue
169. NZ - New Zealand
170. OM - Oman
171. PA - Panama
172. PE - Peru
173. PF - French Polynesia
174. PG - Papua New Guinea
175. PH - Philippines
176. PK - Pakistan
177. PL - Poland
178. PM - St Pierre & Miquelon
179. PN - Pitcairn
180. PR - Puerto Rico
181. PS - Palestine
182. PT - Portugal
183. PW - Palau
184. PY - Paraguay
185. QA - Qatar
186. RE - Réunion
187. RO - Romania
188. RS - Serbia
189. RU - Russia
190. RW - Rwanda
191. SA - Saudi Arabia
192. SB - Solomon Islands
193. SC - Seychelles
194. SD - Sudan
195. SE - Sweden
196. SG - Singapore
197. SH - St Helena
198. SI - Slovenia
199. SJ - Svalbard & Jan Mayen
200. SK - Slovakia
201. SL - Sierra Leone
202. SM - San Marino
203. SN - Senegal
204. SO - Somalia
205. SR - Suriname
206. SS - South Sudan
207. ST - Sao Tome & Principe
208. SV - El Salvador
209. SX - St Maarten (Dutch)
210. SY - Syria
211. SZ - Eswatini (Swaziland)
212. TC - Turks & Caicos Is
213. TD - Chad
214. TF - French Southern & Antarctic Lands
215. TG - Togo
216. TH - Thailand
217. TJ - Tajikistan
218. TK - Tokelau
219. TL - East Timor
220. TM - Turkmenistan
221. TN - Tunisia
222. TO - Tonga
223. TR - Turkey
224. TT - Trinidad & Tobago
225. TV - Tuvalu
226. TW - Taiwan
227. TZ - Tanzania
228. UA - Ukraine
229. UG - Uganda
230. UM - US minor outlying islands
231. US - United States
232. UY - Uruguay
233. UZ - Uzbekistan
234. VA - Vatican City
235. VC - St Vincent
236. VE - Venezuela
237. VG - Virgin Islands (UK)
238. VI - Virgin Islands (US)
239. VN - Vietnam
240. VU - Vanuatu
241. WF - Wallis & Futuna
242. WS - Samoa (western)
243. YE - Yemen
244. YT - Mayotte
245. ZA - South Africa
246. ZM - Zambia
247. ZW - Zimbabwe